@@ -1,8 +1,5 @@
-combns <-
-function (x) 
-{
+combns <- function(x) {
     ans <- t(combn(seq(x), 2))
     ans <- cbind(ans, seq.int(nrow(ans)))
     ans
 }
-
