@@ -1,6 +1,4 @@
-print.LORgee <-
-function (x, ...) 
-{
+print.LORgee <- function(x, ...) {
     cat("Call:\n")
     print(x$call)
     cat("\nNumber of clusters:", x$max.id, "\n")
@@ -14,12 +12,12 @@ function (x, ...)
     if (6 <= nrow(x$local.odds.ratios$theta)) {
         cat("\nLocal Odds Ratios Structure[1:6,1:6]\n")
         print(x$local.odds.ratios$theta[1:6, 1:6])
-    }
-    else {
+    } else {
         cat("\nLocal Odds Ratios Estimates[1:6,1:6]\n")
         print(x$local.odds.ratios$theta)
     }
     if (!is.null(x$pvalue)) 
-        cat("\npvalue of Null model:", ifelse(x$pvalue<0.0001,"<0.0001", round(x$pvalue,4)), "\n")
+        cat("\npvalue of Null model:", ifelse(x$pvalue < 1e-04, "<0.0001", 
+            round(x$pvalue, 4)), "\n")
 }
 
