@@ -1,6 +1,4 @@
-print.summary.LORgee <-
-function (x, ...) 
-{
+print.summary.LORgee <- function(x, ...) {
     cat(x$title, "\n")
     cat(x$version, "\n")
     cat("\nLink :", x$link, "\n")
@@ -23,6 +21,7 @@ function (x, ...)
     cat("\nLocal Odds Ratios Estimates:\n")
     print(round(x$local.odds.ratios$theta, 3))
     if (!is.null(x$pvalue)) 
-        cat("\npvalue of Null model:",ifelse(x$pvalue<=0.0001,"<0.0001",x$pvalue), "\n")
+        cat("\npvalue of Null model:", ifelse(x$pvalue <= 1e-04, "<0.0001", 
+            x$pvalue), "\n")
 }
 
